diff --git a/beta/src/components/MDX/Sandpack/SandpackRoot.tsx b/beta/src/components/MDX/Sandpack/SandpackRoot.tsx
index ef396405..316a4f73 100644
--- a/beta/src/components/MDX/Sandpack/SandpackRoot.tsx
+++ b/beta/src/components/MDX/Sandpack/SandpackRoot.tsx
@@ -74,6 +74,7 @@ function SandpackRoot(props: SandpackProps) {
hidden: true,
};
+ debugger;
return (
div {
}
/**
* For iOS: prevent browser zoom when clicking on sandbox
*/
@media screen and (max-width: 768px) {
@supports (-webkit-overflow-scrolling: touch) {
- .cm-content {
+ .sandbox .cm-content,
+ .sandbox .sp-code-editor .sp-pre-placeholder {
font-size: initial;
}
.DocSearch-Input {
@@ -74,6 +74,7 @@ function SandpackRoot(props: SandpackProps) {
}
/**
- * For iOS: prevent browser zoom when clicking on sandbox
+ * For iOS: prevent browser zoom when clicking on sandbox.
+ * Does NOT apply to code blocks.
*/